<?php

/**
 * @file
 * Administrative pages of usercentrics module.
 */

/**
 * Builds configuration form.
 *
 * @ingroup forms
 */
function usercentrics_config_form(array $form, array &$form_state) {

  $form['usercentrics_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable usercentrics CMP'),
    '#description' => t('Enable usercentrics CMP and adapt JS for Matomo and Google Analytics.'),
    '#default_value' => variable_get('usercentrics_enabled', FALSE),
  );
  $form['usercentrics_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Usercentrics ID'),
    '#description' => t('The ID for usage of usercentrics CMP.'),
    '#default_value' => variable_get('usercentrics_id', ''),
  );
  $form['usercentrics_version'] = array(
    '#type' => 'textfield',
    '#title' => t('Usercentrics Version string'),
    '#description' => t('e.g. <em>preview</em>'),
    '#default_value' => variable_get('usercentrics_version', ''),
  );
  $form['usercentrics_smart_data_protect_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable usercentrics Smart Data Protection'),
    '#description' => t('Enable usercentrics Smart Data Protection for 2-Klick.'),
    '#default_value' => variable_get('usercentrics_smart_data_protect_enabled', FALSE),
  );
  $form['usercentrics_exclude_roles'] = [
    '#title' => t('Exclude following roles fom Usercentrics'),
    '#type' => 'select',
    '#multiple' => TRUE,
    '#description' => 'Select the roles to exclude from Usercentrics.',
    '#options' => user_roles(),
    '#default_value' => variable_get('usercentrics_exclude_roles', []),
  ];

  // Get all implementations an build form.
  $implementations = usercentrics_get_implementations();
  $implementation_settings = variable_get('usercentrics_implementations', []);
  $form['usercentrics_implementations'] = array(
    '#type' => 'fieldset',
    '#title' => t('Enable usercentrics for the following scripts:'),
    '#tree' => TRUE,
  );
  foreach ($implementations as $implementation => $data) {
    if (isset($implementation_settings[$implementation])) {
      $default_value = $implementation_settings[$implementation]['enabled'];
      $default_attribute = $implementation_settings[$implementation]['attribute'];
    }
    else {
      // Per default new modules are enabled.
      $default_value = TRUE;
      $default_attribute = $data['attribute'];
    }
    $form['usercentrics_implementations'][$implementation] = array(
      '#type' => 'fieldset',
      '#title' => $data['title'],
      '#description' => $data['description'],
      '#tree' => TRUE,
    );
    $form['usercentrics_implementations'][$implementation]['enabled'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enabled'),
      '#default_value' => $default_value,
    );
    $form['usercentrics_implementations'][$implementation]['attribute'] = array(
      '#type' => 'textfield',
      '#title' => t('Override Data-Attribute'),
      '#description' => t('Default value: <em>@attribute</em>', array('@attribute' => $data['attribute'])),
      '#default_value' => $default_attribute,
    );
  }

  return system_settings_form($form);
}
