<?php

/**
 * @file
 * Hooks for usercentrics module.
 */

/**
 * Add own implementation for usercentrics.
 *
 * With this hook you can create your own services
 * managed by usercentrics module.
 * The attribute-string must be identically to
 * the Data Processing Services in usercentrics UI.
 * For callback-examples see usercentrics_callback_gtm()
 * in usercentrics.module.
 *
 * @return array
 *   The array of information about your implementation.
 */
function hook_usercentrics_info() {
  $result = [];
  $result['myservice'] = [
    'title' => 'My Service',
    'description' => 'Implementation for my service.',
    'attribute' => 'My Service',
    'callback' => 'mymodule_callback_myservice',
  ];
  return $result;
}

/**
 * Alter existing implementations.
 *
 * If you want to override the callback-function of an existing
 * implementation or to change the attribute programmatically
 * you can use this alter-hook.
 *
 * @param array $implementations
 *   A multidimensional array of implementations.
 */
function hook_usercentrics_info_alter(array &$implementations) {
  // Override data-attribute for my own matomo service.
  if (isset($implementations['matomo'])) {
    $implementations['matomo']['attribute'] = 'My Matomo Service';
  }
}

/**
 * Example-Callback-function.
 *
 * @param string $type
 *   Callback is called twice: 1st hook_js_alter, 2nd hook_pre_render_scripts.
 * @param array $script
 *   The script-Array, depending von $ype.
 *
 * @return bool
 *   TRUE means: usercentrics-script found.
 */
function example_usecentrics_callback($type, array $script) {
  switch ($type) {
    case 'js_alter':
      if (isset($script['data'])) {
        if (strpos($script['data'], 'my-js-file.js') !== FALSE) {
          return TRUE;
        }
      }
      break;

    case 'pre_render_scripts':
      if (isset($script['#attributes']['src'])) {
        if (strpos($script['#attributes']['src'], 'my-js-file.js') !== FALSE) {
          return TRUE;
        }
      }
      break;
  }
  return FALSE;
}
